function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

import React, { useCallback, useEffect, useState } from 'react';
import { Pressable, StyleSheet, View } from 'react-native';
import Popover from './Popover';
export default (({
  action = 'press',
  animated,
  animationType,
  backgroundColor,
  children,
  caret,
  caretPosition,
  content,
  numberOfLines,
  onAction,
  position = 'top',
  style,
  visible
}) => {
  const [popoverVisible, setPopoverVisible] = useState(false);
  const [popoverOffset, setPopoverOffset] = useState({
    left: 0,
    top: 0
  });
  const [popoverLayout, setPopoverLayout] = useState({
    width: 0,
    height: 0
  });
  const [childrenLayout, setChildrenLayout] = useState({
    width: 0,
    height: 0
  });
  const isInteractive = typeof visible === 'undefined';
  const handlers = {};

  if (isInteractive) {
    if (action === 'hover') {
      handlers.onHoverIn = () => {
        setPopoverVisible(true);
        onAction === null || onAction === void 0 ? void 0 : onAction(true);
      };

      handlers.onHoverOut = () => {
        setPopoverVisible(false);
        onAction === null || onAction === void 0 ? void 0 : onAction(false);
      };
    } else if (action === 'press') {
      handlers.onPress = () => {
        setPopoverVisible(visible => {
          onAction === null || onAction === void 0 ? void 0 : onAction(!visible);
          return !visible;
        });
      };
    } else {
      handlers.onLongPress = () => {
        setPopoverVisible(visible => {
          onAction === null || onAction === void 0 ? void 0 : onAction(!visible);
          return !visible;
        });
      };
    }
  }

  const handlePopoverLayout = useCallback(event => {
    const {
      width,
      height
    } = event.nativeEvent.layout;
    setPopoverLayout({
      width,
      height
    });
  }, []);
  const handleChildrenLayout = useCallback(event => {
    const {
      width,
      height
    } = event.nativeEvent.layout;
    setChildrenLayout({
      width,
      height
    });
  }, []);
  useEffect(() => {
    let left = 0;
    let top = 0;

    switch (position) {
      case 'right':
      case 'left':
        top = (popoverLayout.height - childrenLayout.height) / 2;
        break;

      case 'top':
      case 'bottom':
        left = (popoverLayout.width - childrenLayout.width) / 2;
        break;
    }

    setPopoverOffset({
      left,
      top
    });
  }, [childrenLayout, popoverLayout, position]);
  return /*#__PURE__*/React.createElement(View, {
    style: styles.container
  }, /*#__PURE__*/React.createElement(Popover, {
    animated: animated,
    animationType: animationType,
    backgroundColor: backgroundColor,
    caret: caret,
    caretPosition: caretPosition,
    numberOfLines: numberOfLines,
    onLayout: handlePopoverLayout,
    position: position,
    visible: isInteractive ? popoverVisible : visible,
    style: [position === 'top' && styles.popoverTop, position === 'bottom' && styles.popoverBottom, position === 'left' && {
      alignItems: 'flex-end',
      right: childrenLayout.width
    }, position === 'right' && {
      left: childrenLayout.width
    }, {
      position: 'absolute',
      marginLeft: popoverOffset.left * -1,
      marginTop: popoverOffset.top * -1
    }, style]
  }, content), /*#__PURE__*/React.createElement(Pressable, _extends({
    onLayout: handleChildrenLayout
  }, handlers), children));
});
const styles = StyleSheet.create({
  container: {
    position: 'relative',
    zIndex: 1
  },
  popoverTop: {
    bottom: '100%'
  },
  popoverBottom: {
    top: '100%'
  }
});
//# sourceMappingURL=Popable.js.map